@@ -28,7 +28,7 @@ Implementation Notes
 """
 from micropython import const
 
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 
 
 __version__ = "0.0.0-auto.0"
